@@ -11,6 +11,8 @@ General conventions:
     like it mutates an instance actually returns a separate instance with the
     change.
 * Unless explictly specified otherwise, all sorting is in ascending order.
+* Unless explictly specified otherwise, elements with zero quantity, rolls, etc.
+    are considered.
 * The words "min" and "max" refer to outcomes, and the words "low" and "high"
 refer to dice in a pool.
 """
@@ -20,20 +22,21 @@ __docformat__ = 'google'
 # Expose certain names at top-level.
 
 from icepool.die.func import (standard, d, __getattr__, bernoulli, coin,
-                              from_cweights, from_sweights, from_rv,
-                              min_outcome, max_outcome, align, align_range,
-                              reduce, accumulate, apply, apply_sorted)
+                              from_cumulative_quantities, from_rv, min_outcome,
+                              max_outcome, align, align_range, reduce,
+                              accumulate, apply, apply_sorted)
 
+from icepool.population import Population
 from icepool.die.die import Die
 from icepool.die.die_with_truth import DieWithTruth
 
 from icepool.counts import CountsKeysView, CountsValuesView, CountsItemsView
 
-from icepool.die.keep import lowest, highest
+from icepool.die.lowest_highest import lowest, highest
 
 from icepool.pool import Pool, standard_pool, clear_pool_cache
-from icepool.gen import OutcomeCountGen, GenGenerator
-from icepool.eval import OutcomeCountEval, WrapFuncEval, JointEval, SumGen, sum_gen, enumerate_gen, FindBestSet, FindBestRun
+from icepool.outcome_count_generator import OutcomeCountGenerator, NextOutcomeCountGenerator
+from icepool.outcome_count_evaluator import OutcomeCountEvaluator, WrapFuncEvaluator, JointEvaluator, EvaluateSum, evaluate_sum, enumerate_sorted, FindBestSet, FindBestRun
 
 from icepool.deck import Deck
 from icepool.deal import Deal
@@ -50,10 +53,10 @@ Reroll = SpecialValue.Reroll
 """Indicates an outcome should be rerolled (with no max depth)."""
 
 __all__ = [
-    'standard', 'd', 'bernoulli', 'coin', 'Die', 'CountsKeysView',
-    'CountsValuesView', 'CountsItemsView', 'from_cweights', 'from_sweights',
+    'standard', 'd', 'bernoulli', 'coin', 'Die', 'Population', 'CountsKeysView',
+    'CountsValuesView', 'CountsItemsView', 'from_cumulative_quantities',
     'from_rv', 'align', 'align_range', 'lowest', 'highest', 'min_outcome',
     'max_outcome', 'reduce', 'accumulate', 'apply', 'apply_sorted', 'Reroll',
-    'OutcomeCountGen', 'Pool', 'standard_pool', 'OutcomeCountEval', 'JointEval',
-    'SumGen', 'Deck', 'Deal', 'clear_pool_cache'
+    'OutcomeCountGenerator', 'Pool', 'standard_pool', 'OutcomeCountEvaluator',
+    'JointEvaluator', 'EvaluateSum', 'Deck', 'Deal', 'clear_pool_cache'
 ]
